==> plugin-file-2.0.11-1-sources.jar: com/ohaotian/plugin/file/fastdfs/FastdfsFileClient.java <==
package com.ohaotian.plugin.file.fastdfs;

import com.ohaotian.plugin.base.exception.ZTBusinessException;
import com.ohaotian.plugin.file.AbstractFileClient;
import com.ohaotian.plugin.file.constant.FileConfig;
import com.ohaotian.plugin.file.constant.FileType;
import com.ohaotian.plugin.file.util.FileUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.InputStream;

/**
 * 标题：使用FastDFS进行文件上传与下载
 * <p>
 * 说明：使用FastDFS进行文件上传与下载
 * <br>
 * 时间：2018/07/09<br>
 * 版权：copyright © 2018 www.tydic.com Inc. All rights reserved.
 * </p>
 *
 * @author ZhangCheng
 */
public class FastdfsFileClient extends AbstractFileClient {

    private static final Logger logger = LoggerFactory.getLogger(FastdfsFileClient.class);

    private FastdfsConfig fastdfsConfig;

    @Value("${plugin.file.blackType:exe;bat;js;html;dll;jsp;}")
    private String fileUploadBlackType;

    public FastdfsFileClient(FastdfsConfig fastdfsConfig){
        this.fastdfsConfig = fastdfsConfig;
    }

    /**
     * 上传文件通过输入流
     *
     * @param uploadFilePath 文件路径
     * @param fileName       文件名称
     * @param inputStream    输入流
     * @return 文件路径及名称
     */
    @Override
    public String uploadFileByInputStream(String uploadFilePath, String fileName, InputStream inputStream) {
        byte[] bytes = FileUtils.input2byte(inputStream);
        if (fileUploadBlackType.contains(FileUtils.getType(bytes))&&!FileUtils.ext(fileName).equals("txt")&&!FileUtils.ext(fileName).equals("p12")&&!FileUtils.ext(fileName).equals("pfx")){
            throw new ZTBusinessException("禁止上传该文件，请更换后重新上传");
        }

        FastdfsFileInfo fileInfo = FastdfsUtil.uploadFile(fileName,fastdfsConfig,new ByteArrayInputStream(bytes),uploadFilePath);
        return FastdfsFileInfo.toFilePath(fileInfo);
    }

    /**
     * 下载为文件通过文件路径及名称
     *
     * @param filePath 文件路径及名称
     * @return 文件
     */
    @Override
    public File downloadToFile(String filePath) {
        return FastdfsUtil.downloadFile(FastdfsFileInfo.toFastdfsFileInfo(filePath),fastdfsConfig);
    }

    /**
     * 下载为输入流通过文件路径及名称
     *
     * @param filePath 文件路径及名称
     * @return 输入流
     */
    @Override
    public InputStream downLoadToInputStream(String filePath) {
        return FastdfsUtil.downloadByInputStream(FastdfsFileInfo.toFastdfsFileInfo(filePath),fastdfsConfig);
    }

    /**
     * 获取文件类型
     *
     * @return 文件类型
     */
    @Override
    protected FileType getFileType() {
        return FileType.FASTDFS;
    }

}

==> plugin-file-2.1.1-5-20230529.084811-4-sources.jar: com/ohaotian/plugin/file/fastdfs/FastdfsFileClient.java <==
package com.ohaotian.plugin.file.fastdfs;

import com.ohaotian.plugin.base.exception.ZTBusinessException;
import com.ohaotian.plugin.file.AbstractFileClient;
import com.ohaotian.plugin.file.constant.FileConfig;
import com.ohaotian.plugin.file.constant.FileType;
import com.ohaotian.plugin.file.util.FileUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Value;

import java.io.ByteArrayInputStream;
import java.io.File;
import java.io.InputStream;

/**
 * 标题：使用FastDFS进行文件上传与下载
 * <p>
 * 说明：使用FastDFS进行文件上传与下载
 * <br>
 * 时间：2018/07/09<br>
 * 版权：copyright © 2018 www.tydic.com Inc. All rights reserved.
 * </p>
 *
 * @author ZhangCheng
 */
public class FastdfsFileClient extends AbstractFileClient {

    private static final Logger logger = LoggerFactory.getLogger(FastdfsFileClient.class);

    private FastdfsConfig fastdfsConfig;

    @Value("${plugin.file.blackType:exe;bat;js;html;dll;jsp;}")
    private String fileUploadBlackType;

    public FastdfsFileClient(FastdfsConfig fastdfsConfig){
        this.fastdfsConfig = fastdfsConfig;
    }

    /**
     * 上传文件通过输入流
     *
     * @param uploadFilePath 文件路径
     * @param fileName       文件名称
     * @param inputStream    输入流
     * @return 文件路径及名称
     */
    @Override
    public String uploadFileByInputStream(String uploadFilePath, String fileName, InputStream inputStream) {
        byte[] bytes = FileUtils.input2byte(inputStream);
        String fileExtName = FileUtils.ext(fileName);
        if (fileUploadBlackType.contains(FileUtils.getType(bytes))
                &&!"mp4".equals(fileExtName)
                &&!"json".equals(fileExtName)
                &&!"txt".equals(fileExtName)
                &&!"p12".equals(fileExtName)
                &&!"pfx".equals(fileExtName)
                &&!"cer".equals(fileExtName)){
            throw new ZTBusinessException("禁止上传该文件，请更换后重新上传");
        }

        FastdfsFileInfo fileInfo = FastdfsUtil.uploadFile(fileName,fastdfsConfig,new ByteArrayInputStream(bytes),uploadFilePath);
        return FastdfsFileInfo.toFilePath(fileInfo);
    }

    /**
     * 下载为文件通过文件路径及名称
     *
     * @param filePath 文件路径及名称
     * @return 文件
     */
    @Override
    public File downloadToFile(String filePath) {
        return FastdfsUtil.downloadFile(FastdfsFileInfo.toFastdfsFileInfo(filePath),fastdfsConfig);
    }

    /**
     * 下载为输入流通过文件路径及名称
     *
     * @param filePath 文件路径及名称
     * @return 输入流
     */
    @Override
    public InputStream downLoadToInputStream(String filePath) {
        return FastdfsUtil.downloadByInputStream(FastdfsFileInfo.toFastdfsFileInfo(filePath),fastdfsConfig);
    }

    /**
     * 获取文件类型
     *
     * @return 文件类型
     */
    @Override
    protected FileType getFileType() {
        return FileType.FASTDFS;
    }

}
